if [ ! -e /etc/nginx/fastcgi.conf ]
then
    /usr/bin/mkdir -p /etc/nginx
    /usr/bin/cp /etc/defaults/etc/nginx/fastcgi.conf /etc/nginx/fastcgi.conf
fi

if [ ! -e /etc/nginx/fastcgi_params ]
then
    /usr/bin/mkdir -p /etc/nginx
    /usr/bin/cp /etc/defaults/etc/nginx/fastcgi_params /etc/nginx/fastcgi_params
fi

if [ ! -e /etc/nginx/koi-utf ]
then
    /usr/bin/mkdir -p /etc/nginx
    /usr/bin/cp /etc/defaults/etc/nginx/koi-utf /etc/nginx/koi-utf
fi

if [ ! -e /etc/nginx/koi-win ]
then
    /usr/bin/mkdir -p /etc/nginx
    /usr/bin/cp /etc/defaults/etc/nginx/koi-win /etc/nginx/koi-win
fi

if [ ! -e /etc/nginx/mime.types ]
then
    /usr/bin/mkdir -p /etc/nginx
    /usr/bin/cp /etc/defaults/etc/nginx/mime.types /etc/nginx/mime.types
fi

if [ ! -e /etc/nginx/nginx.conf ]
then
    /usr/bin/mkdir -p /etc/nginx
    /usr/bin/cp /etc/defaults/etc/nginx/nginx.conf /etc/nginx/nginx.conf
fi

if [ ! -e /etc/nginx/scgi_params ]
then
    /usr/bin/mkdir -p /etc/nginx
    /usr/bin/cp /etc/defaults/etc/nginx/scgi_params /etc/nginx/scgi_params
fi

if [ ! -e /etc/nginx/uwsgi_params ]
then
    /usr/bin/mkdir -p /etc/nginx
    /usr/bin/cp /etc/defaults/etc/nginx/uwsgi_params /etc/nginx/uwsgi_params
fi

if [ ! -e /etc/nginx/win-utf ]
then
    /usr/bin/mkdir -p /etc/nginx
    /usr/bin/cp /etc/defaults/etc/nginx/win-utf /etc/nginx/win-utf
fi

